.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`transform`
========================
.. automodule:: skimage.transform

.. currentmodule:: skimage.transform
.. autosummary::

   skimage.transform.downscale_local_mean
   skimage.transform.estimate_transform
   skimage.transform.frt2
   skimage.transform.hough_circle
   skimage.transform.hough_circle_peaks
   skimage.transform.hough_ellipse
   skimage.transform.hough_line
   skimage.transform.hough_line_peaks
   skimage.transform.ifrt2
   skimage.transform.integral_image
   skimage.transform.integrate
   skimage.transform.iradon
   skimage.transform.iradon_sart
   skimage.transform.match_histograms
   skimage.transform.matrix_transform
   skimage.transform.order_angles_golden_ratio
   skimage.transform.probabilistic_hough_line
   skimage.transform.pyramid_expand
   skimage.transform.pyramid_gaussian
   skimage.transform.pyramid_laplacian
   skimage.transform.pyramid_reduce
   skimage.transform.radon
   skimage.transform.rescale
   skimage.transform.resize
   skimage.transform.rotate
   skimage.transform.swirl
   skimage.transform.warp
   skimage.transform.warp_coords
   skimage.transform.warp_polar

   skimage.transform.AffineTransform
   skimage.transform.EssentialMatrixTransform
   skimage.transform.EuclideanTransform
   skimage.transform.FundamentalMatrixTransform
   skimage.transform.PiecewiseAffineTransform
   skimage.transform.PolynomialTransform
   skimage.transform.ProjectiveTransform
   skimage.transform.SimilarityTransform


downscale_local_mean
--------------------

.. autofunction:: skimage.transform.downscale_local_mean


.. include:: skimage.transform.downscale_local_mean.examples

estimate_transform
------------------

.. autofunction:: skimage.transform.estimate_transform


.. include:: skimage.transform.estimate_transform.examples

frt2
----

.. autofunction:: skimage.transform.frt2


.. include:: skimage.transform.frt2.examples

hough_circle
------------

.. autofunction:: skimage.transform.hough_circle


.. include:: skimage.transform.hough_circle.examples

hough_circle_peaks
------------------

.. autofunction:: skimage.transform.hough_circle_peaks


.. include:: skimage.transform.hough_circle_peaks.examples

hough_ellipse
-------------

.. autofunction:: skimage.transform.hough_ellipse


.. include:: skimage.transform.hough_ellipse.examples

hough_line
----------

.. autofunction:: skimage.transform.hough_line


.. include:: skimage.transform.hough_line.examples

hough_line_peaks
----------------

.. autofunction:: skimage.transform.hough_line_peaks


.. include:: skimage.transform.hough_line_peaks.examples

ifrt2
-----

.. autofunction:: skimage.transform.ifrt2


.. include:: skimage.transform.ifrt2.examples

integral_image
--------------

.. autofunction:: skimage.transform.integral_image


.. include:: skimage.transform.integral_image.examples

integrate
---------

.. autofunction:: skimage.transform.integrate


.. include:: skimage.transform.integrate.examples

iradon
------

.. autofunction:: skimage.transform.iradon


.. include:: skimage.transform.iradon.examples

iradon_sart
-----------

.. autofunction:: skimage.transform.iradon_sart


.. include:: skimage.transform.iradon_sart.examples

match_histograms
----------------

.. autofunction:: skimage.transform.match_histograms


.. include:: skimage.transform.match_histograms.examples

matrix_transform
----------------

.. autofunction:: skimage.transform.matrix_transform


.. include:: skimage.transform.matrix_transform.examples

order_angles_golden_ratio
-------------------------

.. autofunction:: skimage.transform.order_angles_golden_ratio


.. include:: skimage.transform.order_angles_golden_ratio.examples

probabilistic_hough_line
------------------------

.. autofunction:: skimage.transform.probabilistic_hough_line


.. include:: skimage.transform.probabilistic_hough_line.examples

pyramid_expand
--------------

.. autofunction:: skimage.transform.pyramid_expand


.. include:: skimage.transform.pyramid_expand.examples

pyramid_gaussian
----------------

.. autofunction:: skimage.transform.pyramid_gaussian


.. include:: skimage.transform.pyramid_gaussian.examples

pyramid_laplacian
-----------------

.. autofunction:: skimage.transform.pyramid_laplacian


.. include:: skimage.transform.pyramid_laplacian.examples

pyramid_reduce
--------------

.. autofunction:: skimage.transform.pyramid_reduce


.. include:: skimage.transform.pyramid_reduce.examples

radon
-----

.. autofunction:: skimage.transform.radon


.. include:: skimage.transform.radon.examples

rescale
-------

.. autofunction:: skimage.transform.rescale


.. include:: skimage.transform.rescale.examples

resize
------

.. autofunction:: skimage.transform.resize


.. include:: skimage.transform.resize.examples

rotate
------

.. autofunction:: skimage.transform.rotate


.. include:: skimage.transform.rotate.examples

swirl
-----

.. autofunction:: skimage.transform.swirl


.. include:: skimage.transform.swirl.examples

warp
----

.. autofunction:: skimage.transform.warp


.. include:: skimage.transform.warp.examples

warp_coords
-----------

.. autofunction:: skimage.transform.warp_coords


.. include:: skimage.transform.warp_coords.examples

warp_polar
----------

.. autofunction:: skimage.transform.warp_polar


.. include:: skimage.transform.warp_polar.examples


:class:`AffineTransform`
------------------------


.. autoclass:: AffineTransform
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.transform.AffineTransform.examples


:class:`EssentialMatrixTransform`
---------------------------------


.. autoclass:: EssentialMatrixTransform
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.transform.EssentialMatrixTransform.examples


:class:`EuclideanTransform`
---------------------------


.. autoclass:: EuclideanTransform
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.transform.EuclideanTransform.examples


:class:`FundamentalMatrixTransform`
-----------------------------------


.. autoclass:: FundamentalMatrixTransform
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.transform.FundamentalMatrixTransform.examples


:class:`PiecewiseAffineTransform`
---------------------------------


.. autoclass:: PiecewiseAffineTransform
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.transform.PiecewiseAffineTransform.examples


:class:`PolynomialTransform`
----------------------------


.. autoclass:: PolynomialTransform
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.transform.PolynomialTransform.examples


:class:`ProjectiveTransform`
----------------------------


.. autoclass:: ProjectiveTransform
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.transform.ProjectiveTransform.examples


:class:`SimilarityTransform`
----------------------------


.. autoclass:: SimilarityTransform
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.transform.SimilarityTransform.examples

